ErpColumnConfig class

Constructors

ErpColumnConfig({required String key, required String label, double flex = 1.0, double width = 140, ColumnAlign align = ColumnAlign.left, bool sortable = true, bool searchable = true, bool isDate = false, bool required = false, String? formatter(dynamic value)?})

Properties

align ColumnAlign
final
flex double
final
formatter String? Function(dynamic value)?
final
hashCode int
The hash code for this object.
no setterinherited
isDate bool
final
key String
final
label String
final
required bool
If true, column cannot be removed to pool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchable bool
final
sortable bool
final
width double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited