ErpFieldConfig class

Constructors

ErpFieldConfig({required String key, required String label, ErpFieldType type = ErpFieldType.text, String? hint, bool required = false, bool readOnly = false, bool initialBoolValue = false, int flex = 1, List<ErpDropdownItem>? dropdownItems, String? validator(String?)?, TextInputType? keyboardType, int? maxLines, double? fontSize, Color? fillColor, Color? readOnlyColor, Color? focusColor, double? labelFontSize, Color? labelColor, FontWeight? labelFontWeight, EdgeInsets? contentPadding, int? sectionIndex, int? tabIndex, bool isEntryField = false, bool isCalcField = false, bool isEntryRequired = false, bool isCalculated = false, String? sectionTitle, String? helperText, String? checkboxDbType, bool showAddButton = false})
const

Properties

checkboxDbType String?
final
contentPadding EdgeInsets?
final
final
fillColor Color?
final
flex int
final
focusColor Color?
final
fontSize double?
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
hint String?
final
initialBoolValue bool
final
isCalcField bool
final
isCalculated bool
final
isEntryField bool
final
isEntryRequired bool
final
key String
final
keyboardType TextInputType?
final
label String
final
labelColor Color?
final
labelFontSize double?
final
labelFontWeight FontWeight?
final
maxLines int?
final
readOnly bool
final
readOnlyColor Color?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sectionIndex int?
final
sectionTitle String?
final
showAddButton bool
final
tabIndex int?
final
type ErpFieldType
final
validator String? Function(String?)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited