ErpSearchFieldConfig class

Constructors

ErpSearchFieldConfig({required String key, required String label, String? hint, double flex = 1, double? width})
const

Properties

flex double
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
key String
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited