ReportService class

Constructors

ReportService({required String token, required String url})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final
url String
final

Methods

getReportColumns(int reportId) Future<List>
getReportList(String screen) Future<List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveReport({required int reportId, required String screenName, required String reportName, required List<Map<String, dynamic>> columns}) Future<({String message, bool ok})>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited