ErpDataTable class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ErpDataTable
Constructors
-
ErpDataTable({Key? key, required String title, required List<
ErpColumnConfig> columns, required List<Map< data, List<String, dynamic> >ErpColumnConfig> ? availableExtraColumns, bool showSearch = true, Map<String, dynamic> ? selectedRow, void onRowTap(Map<String, dynamic> row)?, bool dateFilter = false, List<Widget> ? headerActions, String? emptyMessage, Map<String, double> ? totals, required String token, required String url, required bool isReportRow, List<ErpSearchFieldConfig> ? searchFields}) -
const
Properties
-
availableExtraColumns
→ List<
ErpColumnConfig> ? -
final
-
columns
→ List<
ErpColumnConfig> -
final
-
data
→ List<
Map< String, dynamic> > -
final
- dateFilter → bool
-
final
- emptyMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headerActions
→ List<
Widget> ? -
final
- isReportRow → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onRowTap
→ void Function(Map<
String, dynamic> row)? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchFields
→ List<
ErpSearchFieldConfig> ? -
final
-
selectedRow
→ Map<
String, dynamic> ? -
final
-
final
- showSearch → bool
-
final
- title → String
-
final
- token → String
-
final
-
totals
→ Map<
String, double> ? -
final
- url → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ErpDataTable> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited